@@ -7,48 +7,19 @@ All rights reserved.
 
 """
 
-from __future__ import print_function
-
 from colorama import Fore, Style
 
-import sys
 import os, os.path
-import time
-import optparse
 import shutil
 import requests
 import platform
 import subprocess
-import rdflib
 import datetime
-
-try:
-    import cPickle
-except ImportError:
-    import pickle as cPickle
-
-try:
-    import urllib2
-except ImportError:
-    # print("python3")
-    import urllib.request
-    from urllib.request import urlopen
-
-try:
-    from urllib import quote  # Python 2.X
-except ImportError:
-    from urllib.parse import quote  # Python 3+
-
-try:
-    from ConfigParser import SafeConfigParser
-except ImportError:  # python3
-    from configparser import SafeConfigParser
-
-# Fix Python 2.x.
-try:
-    input = raw_input
-except NameError:
-    pass
+import pickle as cPickle
+import urllib.request
+from urllib.request import urlopen
+from urllib.parse import quote  # Python 3+
+from configparser import SafeConfigParser
 
 from . import *
 from .ontospy import Ontospy
@@ -356,7 +327,7 @@ def action_import_folder(location):
 
 def action_webimport(hrlinetop=False):
     """ select from the available online directories for import """
-    DIR_OPTIONS = {1: "http://lov.okfn.org", 2: "http://prefix.cc/popular/"}
+    DIR_OPTIONS = {1: "https://lov.linkeddata.es/", 2: "https://prefix.cc/popular/"}
     selection = None
     while True:
         if hrlinetop:
@@ -393,10 +364,11 @@ def action_webimport(hrlinetop=False):
 
 
 def _import_LOV(
-        baseuri="http://lov.okfn.org/dataset/lov/api/v2/vocabulary/list",
+        baseuri="https://lov.linkeddata.es/dataset/lov/api/v2/vocabulary/list",
         keyword=""):
     """
-    2016-03-02: import from json list
+    Import schemas URI from json list at https://lov.linkeddata.es
+    2022-05-26: updated URL https://github.com/lambdamusic/Ontospy/issues/110
     """
 
     printDebug("----------\nReading source... <%s>" % baseuri)
@@ -457,8 +429,9 @@ def _import_PREFIXCC(keyword=""):
     List models from web catalog (prefix.cc) and ask which one to import
     2015-10-10: originally part of main ontospy; now standalone only
     2016-06-19: eliminated dependency on extras.import_web
+    2022-05-26: added https URL
     """
-    SOURCE = "http://prefix.cc/popular/all.file.vann"
+    SOURCE = "https://prefix.cc/popular/all.file.vann"
     options = []
 
     printDebug("----------\nReading source...")
@@ -665,7 +638,7 @@ def action_visualize(args,
     <fromshell> : the local name is being passed from ontospy shell
     """
 
-    from ..ontodocs.builder import ask_visualization, select_visualization, VISUALIZATIONS_LIST, build_visualization
+    from ..gendocs.actions import ask_visualization, select_visualization, VISUALIZATIONS_LIST, build_visualization
 
     if fromshell:
         ontouri = args
@@ -723,6 +696,6 @@ def action_visualize(args,
 
     # url  = build_viz(ontouri, g, viztype, path)
     printDebug("Building visualization...", dim=True)
-    url = build_visualization(ontouri, g, viztype, path, title, theme)
+    url = build_visualization(g, viztype, path, title, theme)
 
     return url
