@@ -5,21 +5,20 @@ Unit test stub for ontosPy
 
 Run like this:
 
-:path/to/ontospyProject>python -m ontospy.tests.test_sparql
+$ python -m ontospy.tests.test_sparql
 
 """
 
 from __future__ import print_function
-
+import time
 import unittest, os, sys
 from .. import *
 from ..core import *
 from ..core.utils import *
 
 
-
 # sanity check
-print("-------------------\nOntospy ",  VERSION, "\n-------------------")
+printDebug(f"-------------------\nOntospy {VERSION}\n-------------------")
 
 
 
@@ -27,13 +26,19 @@ class TestSparqlStore(unittest.TestCase):
 
     ENDPOINT = "http://dbpedia.org/sparql"
 
+    printDebug(f"""\n=================\n
+    \nTEST SPARQL: Loading data from remote endpoint.
+    \n\n=================""", bg="blue", fg="white")
+
+    time.sleep(3)
+    
     def test1_load_dbpedia(self):
 
         """
         Check if the dbpedia endpoint loads ok
         "http://dbpedia.org/sparql"
         """
-        printDebug("=================\nTEST: Loading <%s> endpoint.\n=================" % self.ENDPOINT, "important")
+        printDebug("\n=================\nTEST: Querying <%s> endpoint...\n=================" % self.ENDPOINT, bg="green")
 
         o = Ontospy(sparql_endpoint=self.ENDPOINT, verbose=True)
 
